==> keybase-1.0.41.tar.gz: client-1.0.41/shared/app/push/push.native.js <==
// @flow
import * as React from 'react'
import * as PushGen from '../../actions/push-gen'
import {connect, type TypedState} from '../../util/container'
import {Box, Button, Text, NativeScrollView, NativeImage} from '../../common-adapters/index.native'
import {globalStyles, globalColors, globalMargins} from '../../styles'

type Props = {
  permissionsRequesting: boolean,
  onRequestPermissions: () => void,
  onNoPermissions: () => void,
}

const Push = (props: Props) => (
  <NativeScrollView style={{width: '100%', height: '100%'}}>
    <Box
      style={{
        ...globalStyles.flexBoxColumn,
        alignItems: 'center',
        backgroundColor: globalColors.white,
        justifyContent: 'center',
        width: '100%',
      }}
    >
      <Box style={{padding: globalMargins.small, width: '100%'}}>
        <Text
          type="Header"
          style={{
            marginBottom: globalMargins.medium,
            marginTop: globalMargins.medium,
            textAlign: 'center',
          }}
        >
          Please turn on notifications!
        </Text>
        <Box style={{height: 270, width: '100%'}}>
          <NativeImage
            resizeMode="contain"
            source={require('../../images/illustrations/illustration-turn-on-notifications-460-x-252.png')}
          />
        </Box>
        <Text type="BodySmallSemibold" style={{textAlign: 'center', color: globalColors.black}}>
          It's{' '}
          <Text type="BodySmallSemiboldItalic" style={{color: globalColors.black}}>
            very
          </Text>{' '}
          important you enable notifications.
        </Text>
        <Text
          type="BodySmall"
          style={{
            textAlign: 'center',
            marginTop: globalMargins.small,
            marginBottom: globalMargins.small,
            color: globalColors.black,
          }}
        >
          This phone may need to perform crypto for you, which the Keybase servers cannot do. For example, if
          you provision a new device, this phone will be contacted.
        </Text>
        <Button
          type="Primary"
          fullWidth={true}
          style={{marginBottom: 10}}
          onClick={props.onRequestPermissions}
          label="Got it"
          waiting={props.permissionsRequesting}
        />
        <Button
          type="Secondary"
          fullWidth={true}
          style={{marginBottom: 10}}
          onClick={props.onNoPermissions}
          label="No thanks"
        />
      </Box>
    </Box>
  </NativeScrollView>
)

export default connect(
  (state: TypedState) => {
    const {permissionsRequesting} = state.push
    return {
      permissionsRequesting,
    }
  },
  (dispatch: any) => {
    return {
      onRequestPermissions: () => dispatch(PushGen.createPermissionsRequest()),
      onNoPermissions: () => dispatch(PushGen.createPermissionsNo()),
    }
  }
)(Push)

==> keybase-2.5.1.tar.gz: client-2.5.1/shared/app/push/push.native.js <==
// @flow
import * as React from 'react'
import * as Constants from '../../constants/push'
import * as PushGen from '../../actions/push-gen'
import {connect} from '../../util/container'
import {
  Box,
  Button,
  Text,
  NativeScrollView,
  NativeImage,
  WaitingButton,
} from '../../common-adapters/mobile.native'
import {globalStyles, globalColors, globalMargins} from '../../styles'

type Props = {
  onRequestPermissions: () => void,
  onNoPermissions: () => void,
  waitingKey: string,
}

const Push = (props: Props) => (
  <NativeScrollView style={{width: '100%', height: '100%'}}>
    <Box
      style={{
        ...globalStyles.flexBoxColumn,
        alignItems: 'center',
        backgroundColor: globalColors.white,
        justifyContent: 'center',
        width: '100%',
      }}
    >
      <Box style={{padding: globalMargins.small, width: '100%'}}>
        <Text
          type="Header"
          style={{
            marginBottom: globalMargins.small,
            marginTop: globalMargins.small,
            textAlign: 'center',
          }}
        >
          Please turn on notifications!
        </Text>
        <NativeImage
          style={{height: 200, width: '170%', resizeMode: 'contain'}}
          source={require('../../images/illustrations/illustration-turn-on-notifications-460-x-252.png')}
        />
        <Text type="BodySmallSemibold" style={{textAlign: 'center', color: globalColors.black}}>
          It's{' '}
          <Text type="BodySmallSemiboldItalic" style={{color: globalColors.black}}>
            very
          </Text>{' '}
          important you enable notifications.
        </Text>
        <Text
          type="BodySmall"
          style={{
            textAlign: 'center',
            marginTop: globalMargins.small,
            marginBottom: globalMargins.small,
            color: globalColors.black,
          }}
        >
          This phone may need to perform crypto for you, which the Keybase servers cannot do. For example, if
          you provision a new device, this phone will be contacted.
        </Text>
        <WaitingButton
          type="Primary"
          fullWidth={true}
          style={{marginBottom: 10}}
          onClick={props.onRequestPermissions}
          label="Got it"
          waitingKey={Constants.permissionsRequestingWaitingKey}
        />
        <Button
          type="Secondary"
          fullWidth={true}
          style={{marginBottom: 10}}
          onClick={props.onNoPermissions}
          label="No thanks"
        />
      </Box>
    </Box>
  </NativeScrollView>
)

const mapStateToProps = () => ({})

export default connect(mapStateToProps, (dispatch: any) => {
  return {
    onNoPermissions: () => dispatch(PushGen.createPermissionsNo()),
    onRequestPermissions: () => dispatch(PushGen.createPermissionsRequest()),
    waitingKey: Constants.permissionsRequestingWaitingKey,
  }
})(Push)
